import unittest
import math
from basic_division import Division


class DivisionTestCase(unittest.TestCase):

    def setUp(self):
        self.division = Division(2)

    def test_zero(self):
        """Test 0 divided by 2"""

        # 0 divided by 2 returns 0.0
        result = self.division.divide(0)
        self.assertEqual(result, 0.0)

    def test_divide_by_zero(self):
        """Test Int divided by 0"""

        self.division_by_zero = Division(0)
        with self.assertRaises(ZeroDivisionError):
            self.division_by_zero.divide(5)

    def test_natural_number(self):
        """Test natural number 5 divided by 2"""

        # 5 divided by 2 returns 2.5
        result = self.division.divide(5)
        self.assertEqual(result, 2.5)

    def test_integer_number(self):
        """Test integer number -14 divided by 2"""

        # -14 divided by 2 returns -7
        result = self.division.divide(-14)
        self.assertEqual(result, -7)

    def test_real_number(self):
        """Test real number PI divided by 2"""

        # PI divided by 2 returns 1.5707963267948966
        result = self.division.divide(math.pi)
        self.assertEqual(result, 1.5707963267948966)

    if __name__ == '__main__':
        unittest.main()



class Division:
    """
    Instantiate a division operation.
    Numbers will be divided by the given divisor.

    :param divisor: The divisor.
    :type divisor: int, float
    """

    def __init__(self, divisor):
        self.divisor = divisor

    def divide(self, number):
        """
        Divide a given number by the divisor.

        :param number: The number to divide.
        :type number: int, float

        :return: The result of the division.
        :rtype: int, float
        """

        return number / self.divisor



import unittest
import math
from basic_multplication import Multiplication


class MultiplicationTestCase(unittest.TestCase):

    def setUp(self):
        self.multiplication = Multiplication(2)

    def test_zero(self):
        """Test 0 multiplied by 2"""

        # 0 multiplied by 2 return 0
        result = self.multiplication.multiply(0)
        self.assertEqual(result, 0)

    def test_natural_number(self):
        """Test natural number 5 multiplied by 2"""

        # 5 multiplied by 2 return 10
        result = self.multiplication.multiply(5)
        self.assertEqual(result, 10)

    def test_integer_number(self):
        """Test integer number -7 multiplied by 2"""

        # -7 multiplied by 2 return -14
        result = self.multiplication.multiply(-7)
        self.assertEqual(result, -14)

    def test_rational_number(self):
        """Test rational number 6/17 multiplied by 2"""

        # 6/17 multiplied by 2 return (6/17) * 2
        result = self.multiplication.multiply(6 / 17)
        self.assertEqual(result, (6 / 17) * 2)

    def test_real_number(self):
        """Test real number PI multiplied by 2"""

        # PI multiplied by 2 return 2PI
        result = self.multiplication.multiply(math.pi)
        self.assertEqual(result, math.pi * 2)

    if __name__ == '__main__':
        unittest.main()



from setuptools import setup, find_packages
from codecs import open
from os import path

# The directory containing this file
PWD = path.abspath(path.dirname(__file__))

# Get the long description from the README file
with open(path.join(PWD, 'README.md'), encoding='utf-8') as f:
    long_description = f.read()

# This call to setup() does all the work
setup(
    name="basic-maths",
    version="0.1.6",
    description="Basic maths library for multiplication and division",
    long_description=long_description,
    long_description_content_type="text/markdown",
    # url="https://medium-multiply.readthedocs.io/",
    author="Victor Akinmade",
    author_email="victor@email.com",
    license="MIT",
    classifiers=[
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Operating System :: OS Independent"
    ],
    packages=find_packages(),
    include_package_data=True,
    install_requires=["numpy"]
)